@@ -540,7 +540,9 @@ class _TestBase:
         async def coro():
             pass
 
-        factory = lambda loop, coro: MyTask(coro, loop=loop)
+        factory = lambda loop, coro, **kwargs: MyTask(
+            coro, loop=loop, **kwargs
+        )
 
         self.assertIsNone(self.loop.get_task_factory())
         self.loop.set_task_factory(factory)
@@ -577,7 +579,9 @@ class _TestBase:
         async def coro():
             pass
 
-        factory = lambda loop, coro: MyTask(coro, loop=loop)
+        factory = lambda loop, coro, **kwargs: MyTask(
+            coro, loop=loop, **kwargs
+        )
 
         self.assertIsNone(self.loop.get_task_factory())
         task = self.loop.create_task(coro(), name="mytask")
@@ -860,6 +864,14 @@ class TestBaseUV(_TestBase, UVTestCase):
         self.assertAlmostEqual(handle.when(), loop_t + delay, places=2)
         handle.cancel()
         self.assertTrue(handle.cancelled())
+        self.assertAlmostEqual(handle.when(), loop_t + delay, places=2)
+
+    def test_loop_call_later_handle_when_after_fired(self):
+        fut = self.loop.create_future()
+        handle = self.loop.call_later(0.05, fut.set_result, None)
+        when = handle.when()
+        self.loop.run_until_complete(fut)
+        self.assertEqual(handle.when(), when)
 
 
 class TestBaseAIO(_TestBase, AIOTestCase):
