@@ -452,6 +452,10 @@ class _ContextBaseTests(tb.SSLTestCase):
         self._run_server_test(test, async_sock=True)
 
     def test_create_ssl_server_manual_connection_lost(self):
+        if self.implementation == 'asyncio' and sys.version_info >= (3, 11, 0):
+            # TODO(fantix): fix for 3.11
+            raise unittest.SkipTest('should pass on 3.11')
+
         async def test(proto, cvar, ssl_sock, **_):
             def close():
                 cvar.set('closing')
